==> weld-osgi-bundle-1.1.33.Final-sources.jar: org/jboss/weld/bootstrap/events/ProcessBeanInjectionTarget.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.bootstrap.events;

import org.jboss.weld.bean.AbstractClassBean;
import org.jboss.weld.manager.BeanManagerImpl;

import javax.enterprise.inject.spi.InjectionTarget;
import javax.enterprise.inject.spi.ProcessInjectionTarget;


public class ProcessBeanInjectionTarget<X> extends AbstractProcessInjectionTarget<X> implements ProcessInjectionTarget<X> {

    private final AbstractClassBean<X> classBean;

    public ProcessBeanInjectionTarget(BeanManagerImpl beanManager, AbstractClassBean<X> bean) {
        super(beanManager, bean.getWeldAnnotated());
        this.classBean = bean;
    }

    public InjectionTarget<X> getInjectionTarget() {
        return classBean.getInjectionTarget();
    }

    public void setInjectionTarget(InjectionTarget<X> injectionTarget) {
        classBean.setInjectionTarget(injectionTarget);
    }

}

==> weld-osgi-bundle-3.0.5.Final-sources.jar: org/jboss/weld/bootstrap/events/ProcessBeanInjectionTarget.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.weld.bootstrap.events;

import org.jboss.weld.bean.AbstractClassBean;
import org.jboss.weld.logging.BootstrapLogger;
import org.jboss.weld.manager.BeanManagerImpl;

import javax.enterprise.inject.spi.InjectionTarget;
import javax.enterprise.inject.spi.ProcessInjectionTarget;

public class ProcessBeanInjectionTarget<X> extends AbstractProcessInjectionTarget<X> implements ProcessInjectionTarget<X> {

    private final AbstractClassBean<X> classBean;

    public ProcessBeanInjectionTarget(BeanManagerImpl beanManager, AbstractClassBean<X> bean) {
        super(beanManager, bean.getAnnotated());
        this.classBean = bean;
    }

    public InjectionTarget<X> getInjectionTarget() {
        checkWithinObserverNotification();
        return classBean.getProducer();
    }

    public void setInjectionTarget(InjectionTarget<X> injectionTarget) {
        checkWithinObserverNotification();
        BootstrapLogger.LOG.setInjectionTargetCalled(getReceiver(), getInjectionTarget(), injectionTarget);
        classBean.setProducer(injectionTarget);
    }

}
